# -*- coding: utf-8 -*-

import pygtk
pygtk.require('2.0')
import gtk
import pynotify
import ConfigParser
import sys
import time
import os
import urllib2
import parser
import datetime



class Application:

	def __init__(self, config_file = '.pyguidaTV-settings'):
	
		if not pynotify.init("Basics"):
			print "pynotify not avaible"
			sys.exit(1)
			
		
		self.settings = self.initSettings(config_file)
		self.canali = self.trovaCanali()
		self.parser = parser.MovieParser()
		self.window = self.creaFinestra()
		self.trayicon = self.creaTrayIcon()
		self.notification = self.initNotification()
		
				
	def initSettings(self, config_file):
		
		result = ConfigParser.ConfigParser()
		result.optionxform = lambda x: x #case sensitive :O
		
		dirname, filename = os.path.split(os.path.abspath(sys.argv[0]))
		config_file = os.path.join(dirname, config_file)
		
		if (os.path.exists(config_file)):
			result.read(config_file)
		else:			
			result.read(os.path.join(dirname, 'default'))

		self.config_file = config_file
		return result
		
	def getCanali(self):
		return self.canali
		
	def getTipiCanali(self):
		return ['chiaro']
	
	def trovaCanali(self, tipo = 'chiaro'):
		result = {}
		for c in self.settings.options(tipo):
			result[c] = int(self.settings.get(tipo, c))
			
		return result
	
	def creaFinestra(self):
		
		result = gtk.Window(gtk.WINDOW_TOPLEVEL)
		result.set_title('pyguidaTV')
		
		vbox = gtk.VBox(True, 2)
		label = gtk.Label('Seleziona i canali che ti interessano')
		table = gtk.Table(1, 1, True)
		
		quit = gtk.Button(gtk.STOCK_CLOSE)
		quit.set_use_stock(True)
		quit.connect('clicked', self.hide)
		
		buttons = []
		i, j = 0, 1
		k,l =0, 1
		
		for c, act in self.canali.items():
			b = gtk.CheckButton(c)
			b.set_active(act)
			buttons.append(b)
			table.attach(b, i, j, k, l)
			b.show()
			
			if (k == 0):
				k,l = 1, 2
			else:
				k,l = 0,1
				i = j
				j += 1
		
		label.show()
		table.show()
		quit.show()
		
		vbox.pack_start(label, True, True, 2)
		vbox.pack_start(table, True, True, 2)
		vbox.pack_start(quit, True, True, 2)
		vbox.show()
		
		result.add(vbox)
		result.connect('delete_event', self.hide)
		self.check_buttons = buttons
		
		return result
	
	def creaTrayIcon(self):
		
		result = gtk.StatusIcon()
		dirname, filename = os.path.split(os.path.abspath(sys.argv[0]))
		icon = os.path.join(dirname, 'pyguidaTV-LCD.png')
		result.set_from_file(icon)
		
		menu = gtk.Menu()
		
		oggi = gtk.ImageMenuItem(gtk.STOCK_GO_FORWARD)
		oggi.get_children()[0].set_label('Film di Oggi')
		oggi.connect('activate', self.menu_click, 'oggi')	
			
		domani = gtk.ImageMenuItem(gtk.STOCK_GO_FORWARD)
		domani.get_children()[0].set_label('Film di Domani')
		domani.connect('activate', self.menu_click, 'domani')
		
		preferenze = gtk.ImageMenuItem(gtk.STOCK_PREFERENCES)
		preferenze.get_children()[0].set_label('Preferenze')
		preferenze.connect('activate', self.show_window)
		
		close = gtk.ImageMenuItem(gtk.STOCK_CLOSE)
		close.get_children()[0].set_label('Esci')
		close.connect('activate', self.delete)
		
		menu.append(oggi)
		menu.append(domani)
		menu.append(preferenze)
		menu.append(close)
		
		result.connect('popup-menu', self.popup_menu, menu)
		return result
	
	def initNotification(self):
		result = pynotify.Notification('')
		return result
	
	def mostraFilm(self, giorno = 'oggi', tipo = 'chiaro'):
		
		today = datetime.date.today()
		tomorrow = datetime.date(today.year, today.month, today.day +1)
		
		if (giorno == 'oggi'):
			data = today
		elif (giorno == 'domani'):
			data = tomorrow
		
		tipo = 'tv'
		url = 'http://www.mymovies.it/' + tipo + '/?g='
		arg = str(data.day) + str(data.month) + str(data.year)
		
		html = urllib2.urlopen(url + arg).read()
		canali = self.getCanali()
		self.parser.setParams(html, canali)
		
		listaFilm = self.parser.listaFilm()
		found = str(self.parser.filmTrovati())		
		self.notifica('Film consigliati ' + giorno + ' (' + found + ')')
		
		for film in listaFilm:
			msg = ''
			msg += 'Ore: ' + film['orario'] + '\n'
			msg += 'Voto: ' + film['valutazione'] + '/5' + '\n'
			msg += 'Genere: ' + film['genere'] + '\n'
			msg += film['canale'] + '\n'
			self.notifica(film['titolo'], msg)
	
	def notifica(self, titolo, msg = '', wait = 7):
		self.notification.update(titolo, msg)
		self.notification.show()
		time.sleep(wait)
		
	def mainLoop(self):
		gtk.main()
		return 0
		
	def delete(self, widget, data=None):
		gtk.main_quit()
		
	def hide(self, w, data=None):
		
		for b in self.check_buttons:
			self.settings.set('chiaro', b.get_label(), ('0', '1')[b.get_active()])
			self.settings.write(open(self.config_file, 'w'))
		
		self.canali = self.trovaCanali()
		self.window.hide()
		
	def menu_click(self, w, giorno=None):
		self.mostraFilm(giorno)
		
	def popup_menu(self, w, menu, time, data=None):
		data.show_all()
		data.popup(None, None, None, 3, time)
	
	def show_window(self, w):
		self.window.show()
